import squint.*;
import javax.swing.*;

// ModedPopClient --- This program allows its user to view
// mail messages accessed through a POP client.  The user first
// logs in and then can repeatedly request messages.
public class ModedPopClient extends GUIManager {
    // Change these values to adjust the size of the program's window
    private final int WINDOW_WIDTH  = 650, WINDOW_HEIGHT = 450;
    
    // Information for contacting the mail server
    private final String POPSERVER = "cortland.cs.williams.edu";
    private final int POPPORT = 110;
    
    
    
    // A Pane to hold all the login component
    private JPanel loginInfoPane;
    
    // Width of the fields for the user id and password
    private final int FIELD_INFO_WIDTH = 18;
    
    // Used to enter the POP account identifier and password
    private JTextField user;
    private JPasswordField pass;
        
    // Pressed to login once account info has been entered
    private JButton login;
    
    

    // A pane to hold all the controls used when accessing messages
    private JPanel messageControlPane;
    
    // Size of field used to enter message number
    private final int MESS_NUM_WIDTH = 3;
    
    // Used to enter the number of the message to retrieve
    private JTextField messageNum;
    
    // Used to display the number of message available
    private JLabel messageCount;
        
    // Control buttons to retrieve, compose and log out
    private JButton get;
    private JButton reply;
    private JButton logOut;
    
    // Email messages are displayed in the message text area area
    private final int DISPLAY_WIDTH = 50, DISPLAY_HEIGHT = 20;
    private JTextArea message;
    
    
    
    // The connection to the server
    private NetConnection toServer;
        
   /*
    * Create all the GUI components and display the login components
    */
    public ModedPopClient() {
        this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
        
        // Create components displayed to allow login
        loginInfoPane = new JPanel();
        
        // Each JLabel/JTextArea pair is placed together in a pane of their own
        JPanel curPanel;
        
        // Create fields for entering the account information
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Mail Account:" ) );
        user = new JTextField( FIELD_INFO_WIDTH );
        curPanel.add( user );
        loginInfoPane.add( curPanel );
        
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Password:" ) );
        pass = new JPasswordField( FIELD_INFO_WIDTH );
        curPanel.add( pass );
        loginInfoPane.add( curPanel );
                
        // Display the login components
        contentPane.add( loginInfoPane );
        login = new JButton( "Log in" );
        contentPane.add( login );

        messageControlPane = new JPanel();
        
        // Create a labeled field for the message number
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Retrieve message" ) );
        messageNum = new JTextField( MESS_NUM_WIDTH );
        curPanel.add( messageNum );
        messageCount = new JLabel( "" );
        curPanel.add( messageCount );
        
        messageControlPane.add( curPanel );
        
        // Install the buttons in the message access pane
        get = new JButton( "Get Message" );
        messageControlPane.add( get );
        reply = new JButton( "Compose" );
        messageControlPane.add( reply );
        logOut = new JButton( "Log out" );
        messageControlPane.add( logOut );
        
        message = new JTextArea( DISPLAY_HEIGHT, DISPLAY_WIDTH );
    }
    
    
   /*
    * When the button is clicked, interact with the POP server to
    * log in, log out, or access the requested message.
    */
    public void buttonClicked( JButton which ) {
        String response;
        
        if ( which == login ) {
            
            // Connect to the server
            toServer = new NetConnection( POPSERVER, POPPORT );       
            response = toServer.in.nextLine();
        
            // Send account information
            toServer.out.println( "USER " + user.getText() );
            response = toServer.in.nextLine();
            toServer.out.println( "PASS " + new String( pass.getPassword()) );
            
            // Check that the login was accepted by the server
            response = toServer.in.nextLine();
            
            if ( response.startsWith( "+OK" ) ) {
                // Determine how many message are on the server
                String statInfo;
                String messagesAvail;
                
                toServer.out.println( "STAT" );
                statInfo = toServer.in.nextLine().substring( "STAT".length() );
                messagesAvail = statInfo.substring( 0, statInfo.indexOf( " " ) );
                messageCount.setText( "of " + messagesAvail );
                
                // Display the message access controls
                contentPane.removeAll();
                contentPane.add( messageControlPane );
                contentPane.add( new JScrollPane( message ) );
                
                // select message number 1
                messageNum.setText( "1" );
                messageNum.requestFocus();
                messageNum.selectAll();
                
            } else { // login attempt was rejected
                contentPane.add( 
                   new JLabel( "Login failed.  Check your id and password" ) );
                toServer.close();
            }
            
            
            
        } else if ( which == get ) {
            String retrResponse;
            
            // Retrieve and display the specified email message
            toServer.out.println( "RETR " + messageNum.getText() );
            retrResponse = toServer.in.nextLine();
            
            if ( retrResponse.startsWith( "+OK" ) ) {
                message.setText( "" );
                retrResponse = toServer.in.nextLine();
                while ( ! retrResponse.equals( "." ) ) {
                    message.append( retrResponse + "\n" );
                    retrResponse = toServer.in.nextLine();
                }
            } else {
                message.setText( "Requested message not found." );
            }
         
            // Make it easy to enter the next message number
            messageNum.requestFocus();
            messageNum.selectAll();
            
        } else if ( which == logOut ) {
            
            // Terminate the connection
            toServer.out.println( "QUIT" );
            toServer.close();
            
            // Clear the message area
            message.setText( "" );

            // Display the login components
            contentPane.removeAll();
            contentPane.add( loginInfoPane );
            contentPane.add( login );
            
        } else if ( which == reply ) {
            new SMTPClient();
        }
        validate();
        repaint();
   }
   
   // React to pressing return in the program's text fields by
   // simulating the clicking of the appropriate control buttons
   public void textEntered( JTextField fieldUsed ) {
       if ( fieldUsed == messageNum ) {
           get.doClick();
       } else {
           login.doClick();
       }
   }
}
