import squint.*;
import javax.swing.*;

// PopConnectionClient --- This program allows its user to view
// mail messages accessed through a POP client.  The user first
// logs in and then can repeatedly request messages.
public class PopConnectionClient extends GUIManager {
    // Change these values to adjust the size of the program's window
    private final int WINDOW_WIDTH  = 650;
    private final int WINDOW_HEIGHT = 450;
    
    // Server information
    private final String SERVER_NAME = "cortland.cs.williams.edu";
    private final int POP_PORT = 110;
   
    // COMPONENTS USED DURING THE LOG IN PROCESS
    
    // Used to enter the POP account identifier
    private JTextField user = new JTextField( 20 );
        
    // Used to enter the POP account password
    private JPasswordField pass = new JPasswordField( 15 );
        
    // Pressed to login once account info has been entered
    private JButton login = new JButton( "Log in" );
    
     // A Pane to hold all the login components
    private JPanel loginInfoPane = new JPanel();
    
    
    // COMPONENTS USED WHILE ACCESSING MESSAGES
    
    // Used to enter the number of the message to retrieve
    private JTextField messageNum = new JTextField( 3 );
    
    // Used to display the number of message available
    private JLabel messageCount = new JLabel( "" );
        
    // Pressed to fetch a message
    private JButton get = new JButton( "Get Message" );
    
    // Pressed to respond to a message
    private JButton reply = new JButton( "Compose Reply" );
    
    // Pressed to log out
    private JButton logOut = new JButton( "Log out" );
    
    // A pane to hold all the controls used when accessing messages
    private JPanel messageControlPane = new JPanel();
    
    // Email messages are displayed in this area
    private JTextArea message = new JTextArea( 20, 50 );
    private JScrollPane messagePane = new JScrollPane( message );
        
    
   
    // The connection to the server
    private POPConnection toServer;
        
    // The most recently accessed message
    MailMessage curMessage;
    
    // Create all the GUI components and display the login components
    public void init() {
        this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
        
        JPanel curPanel;
        
        // Create fields for entering the account information
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Mail Account:" ) );
        curPanel.add( user );
        loginInfoPane.add( curPanel );
        
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Password:" ) );
        curPanel.add( pass );
        loginInfoPane.add( curPanel );
                
        // Create a labeled field for the message number
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Retrieve message" ) );
        curPanel.add( messageNum );
        curPanel.add( messageCount );
        
        messageControlPane.add( curPanel );
        
        // Install the buttons in the message access pane
        messageControlPane.add( get );
        messageControlPane.add( reply );
        messageControlPane.add( logOut );
        
        // Display the login components
        contentPane.add( loginInfoPane );
        contentPane.add( login );
    }
    
    

    // When the button is clicked, interact with the POP server to
    // log in, log out, or access the requested message.
    public void buttonClicked( JButton which ) {
        
        if ( which == login ) {
            toServer = new POPConnection( SERVER_NAME, user.getText(),
                                          new String( pass.getPassword() ) );
            
            if ( toServer.isConnected() ) {
                // Determine how many message are on the server
                messageCount.setText( "of " + toServer.messagesAvail() );
                
                // Display the message access controls
                contentPane.removeAll();
                contentPane.add( messageControlPane);
                contentPane.add( messagePane );
                
                // select message number 1
                messageNum.setText( "1" );
                messageNum.requestFocus();
                messageNum.selectAll();
                
            } else {            // login attempt was rejected
                contentPane.add( 
                   new JLabel( "Login failed.  Check your id and password" ) );
                toServer.close();
            }
            
        } else if ( which == get ) {
            
            // Retrieve and display the specified email message
            curMessage =  toServer.getMessage( messageNum.getText() );
            
            if ( curMessage != null ) {
                message.setText( curMessage.getText() );
            } else {
                message.setText( "Requested message not found." );
            }
        
            // Make it easy to enter the next message number
            messageNum.requestFocus();
            messageNum.selectAll();
            
        } else if ( which == logOut ) {
            
            // Terminate the connection
            toServer.close();
            
            // Clear the message area
            message.setText( "" );

            // Display the login components
            contentPane.removeAll();
            contentPane.add( loginInfoPane );
            contentPane.add( login );
            
        } else if ( which == reply ) {    
            // Create a new reply window
            new ReplyWindow( curMessage.getFrom(),
                             user.getText() + "@" + SERVER_NAME,
                             curMessage.getText() );
        }
   }
   
   // React to pressing return in the program's text fields by
   // simulating the clicking of the appropriate control buttons
   public void textEntered( JTextField fieldUsed ) {
       if ( fieldUsed == messageNum ) {
           get.doClick();
       } else {
           login.doClick();
       }
   }
   
   // Start execution when an instance of the program is created
   public PopConnectionClient() {
       this.init();
   }
}