import squint.*;
import javax.swing.*;
import java.net.*;

public class ReplyWindow extends GUIManager
{
   // Change these values to adjust the size of the program's window
   private final int WINDOW_WIDTH  = 550;
   private final int WINDOW_HEIGHT = 500;
   
   // amount of space to allow in a text field for an email address
   private final int ADDR_WIDTH = 30;
   
   // how many characters wide program's text areas should be
   private final int AREA_WIDTH = 42;
   
   // how many lines tall the message area should be
   private final int MESSAGE_LINES = 15;
   
   // how many lines tall the log area should be
   private final int LOG_LINES = 5;

   // address of SMTP server to use
   private final String SMTP_SERVER = "cs.williams.edu";
   
   // Standard port for connection to an SMTP server
   private final int SMTP_PORT = 25;

   // Fields for to and from addresses
   private JTextField from = new JTextField( ADDR_WIDTH );
   private JTextField to = new JTextField( ADDR_WIDTH );
   
   // Area in which user can type message body
   private JTextArea message = new JTextArea( MESSAGE_LINES, AREA_WIDTH );
   
   // Area in which responses from server will be logged
   private JTextArea log = new JTextArea( LOG_LINES, AREA_WIDTH );
   
  /**
   * Place fields and text areas on screen to enable user to
   * enter mail together with a send button.
   */
   public ReplyWindow( String toAddr, String fromAddr, String original) {
      // Create window to hold all the components
      this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
      
      JPanel curPane = new JPanel();
      
      curPane.add( new JLabel( "To" ) );
      to.setText( toAddr );
      curPane.add( to );
      contentPane.add( curPane );
      
      curPane = new JPanel(); 
      curPane.add( new JLabel( "From:" ) );
      from.setText( fromAddr );
      curPane.add( from );
      contentPane.add( curPane );

      contentPane.add ( new JLabel( "Enter your message below") );
      
      message.setText ( "\n\n\n------- original message --------\n\n" + original);
      message.setCaretPosition( 0 );
      contentPane.add( new JScrollPane( message ) );
      
      contentPane.add( new JButton( "Send" ) );
      
      // Hide the log
      // contentPane.add( new JScrollPane( log ) );
      log.setEditable( false );
}

   /*
    * Send a message when the button is clicked
    */
    public void buttonClicked(  ) {
        NetConnection toServer = new NetConnection( SMTP_SERVER, SMTP_PORT );
        log.append( toServer.in.nextLine() + "\n" );
       
        toServer.out.println( "HELO " + this.getHostName() );
        log.append( toServer.in.nextLine() + "\n" );
       
        toServer.out.println( "MAIL FROM: <" + from.getText() +">" );
        log.append( toServer.in.nextLine() + "\n" );
       
        toServer.out.println( "RCPT TO: <" + to.getText() +">" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( "DATA" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( message.getText() );
        toServer.out.println( "." );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.out.println( "QUIT" );
        log.append( toServer.in.nextLine() + "\n" );
        
        toServer.close();
    }
   
}
